import * as utils from './utils';
import baseLogger from './logger';
import EventEmitter from './EventEmitter';

var Connector = function (_EventEmitter) {
  babelHelpers.inherits(Connector, _EventEmitter);

  function Connector(cache, store, services) {
    var options = arguments.length <= 3 || arguments[3] === undefined ? {} : arguments[3];
    babelHelpers.classCallCheck(this, Connector);

    var _this = babelHelpers.possibleConstructorReturn(this, Object.getPrototypeOf(Connector).call(this));

    _this.cache = cache;
    _this.store = store;
    _this.services = services;
    _this.options = options;
    _this.logger = baseLogger.create('cacheConnector');

    _this.cache && _this.cache.init && _this.cache.init(services, options.cache, options);
    return _this;
  }

  babelHelpers.createClass(Connector, [{
    key: 'load',
    value: function load(languages, namespaces, callback) {
      var _this2 = this;

      if (!this.cache) return callback && callback();
      var options = babelHelpers.extends({}, this.cache.options, this.options.cache);

      if (typeof languages === 'string') languages = this.services.languageUtils.toResolveHierarchy(languages);
      if (typeof namespaces === 'string') namespaces = [namespaces];

      if (options.enabled) {
        this.cache.load(languages, function (err, data) {
          if (err) _this2.logger.error('loading languages ' + languages.join(', ') + ' from cache failed', err);
          if (data) {
            for (var l in data) {
              for (var n in data[l]) {
                if (n === 'i18nStamp') continue;
                var bundle = data[l][n];
                if (bundle) _this2.store.addResourceBundle(l, n, bundle);
              }
            }
          }
          if (callback) callback();
        });
      } else {
        if (callback) callback();
      }
    }
  }, {
    key: 'save',
    value: function save() {
      if (this.cache && this.options.cache && this.options.cache.enabled) this.cache.save(this.store.data);
    }
  }]);
  return Connector;
}(EventEmitter);

export default Connector;