import baseLogger from './logger';

var LanguageUtil = function () {
  function LanguageUtil(options) {
    babelHelpers.classCallCheck(this, LanguageUtil);

    this.options = options;

    this.whitelist = this.options.whitelist || false;
    this.logger = baseLogger.create('languageUtils');
  }

  babelHelpers.createClass(LanguageUtil, [{
    key: 'getLanguagePartFromCode',
    value: function getLanguagePartFromCode(code) {
      if (code.indexOf('-') < 0) return code;

      var specialCases = ['nb-NO', 'nn-NO', 'nb-no', 'nn-no'];
      var p = code.split('-');
      return this.formatLanguageCode(specialCases.indexOf(code) > -1 ? p[1].toLowerCase() : p[0]);
    }
  }, {
    key: 'formatLanguageCode',
    value: function formatLanguageCode(code) {
      if (typeof code === 'string' && code.indexOf('-') > -1) {
        var _code$split = code.split('-');

        var _code$split2 = babelHelpers.slicedToArray(_code$split, 2);

        var head = _code$split2[0];
        var tail = _code$split2[1];

        return this.options.lowerCaseLng ? head.toLowerCase() + '-' + tail.toLowerCase() : head.toLowerCase() + '-' + tail.toUpperCase();
      } else {
        return this.options.cleanCode || this.options.lowerCaseLng ? code.toLowerCase() : code;
      }
    }
  }, {
    key: 'isWhitelisted',
    value: function isWhitelisted(code) {
      if (this.options.load === 'languageOnly') code = this.getLanguagePartFromCode(code);
      return !this.whitelist || !this.whitelist.length || this.whitelist.indexOf(code) > -1 ? true : false;
    }
  }, {
    key: 'toResolveHierarchy',
    value: function toResolveHierarchy(code, fallbackCode) {
      var _this = this;

      fallbackCode = fallbackCode || this.options.fallbackLng || [];
      if (typeof fallbackCode === 'string') fallbackCode = [fallbackCode];

      var codes = [];
      var addCode = function addCode(code) {
        if (_this.isWhitelisted(code)) {
          codes.push(code);
        } else {
          _this.logger.warn('rejecting non-whitelisted language code: ' + code);
        }
      };

      if (typeof code === 'string' && code.indexOf('-') > -1) {
        if (this.options.load !== 'languageOnly') addCode(this.formatLanguageCode(code));
        if (this.options.load !== 'currentOnly') addCode(this.getLanguagePartFromCode(code));
      } else if (typeof code === 'string') {
        addCode(this.formatLanguageCode(code));
      }

      fallbackCode.forEach(function (fc) {
        if (codes.indexOf(fc) < 0) addCode(_this.formatLanguageCode(fc));
      });

      return codes;
    }
  }]);
  return LanguageUtil;
}();

;

export default LanguageUtil;