import EventEmitter from './EventEmitter';
import * as utils from './utils';

var ResourceStore = function (_EventEmitter) {
  babelHelpers.inherits(ResourceStore, _EventEmitter);

  function ResourceStore() {
    var data = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
    var options = arguments.length <= 1 || arguments[1] === undefined ? { ns: ['translation'], defaultNS: 'translation' } : arguments[1];
    babelHelpers.classCallCheck(this, ResourceStore);

    var _this = babelHelpers.possibleConstructorReturn(this, Object.getPrototypeOf(ResourceStore).call(this));

    _this.data = data;
    _this.options = options;
    return _this;
  }

  babelHelpers.createClass(ResourceStore, [{
    key: 'addNamespaces',
    value: function addNamespaces(ns) {
      if (this.options.ns.indexOf(ns) < 0) {
        this.options.ns.push(ns);
      }
    }
  }, {
    key: 'removeNamespaces',
    value: function removeNamespaces(ns) {
      var index = this.options.ns.indexOf(ns);
      if (index > -1) {
        this.options.ns.splice(index, 1);
      }
    }
  }, {
    key: 'getResource',
    value: function getResource(lng, ns, key) {
      var options = arguments.length <= 3 || arguments[3] === undefined ? {} : arguments[3];

      var keySeparator = options.keySeparator || this.options.keySeparator;
      if (keySeparator === undefined) keySeparator = '.';

      var path = [lng, ns];
      if (key && typeof key !== 'string') path = path.concat(key);
      if (key && typeof key === 'string') path = path.concat(keySeparator ? key.split(keySeparator) : key);

      if (lng.indexOf('.') > -1) {
        path = lng.split('.');
      }

      return utils.getPath(this.data, path);
    }
  }, {
    key: 'addResource',
    value: function addResource(lng, ns, key, value) {
      var options = arguments.length <= 4 || arguments[4] === undefined ? { silent: false } : arguments[4];

      var keySeparator = this.options.keySeparator;
      if (keySeparator === undefined) keySeparator = '.';

      var path = [lng, ns];
      if (key) path = path.concat(keySeparator ? key.split(keySeparator) : key);

      if (lng.indexOf('.') > -1) {
        path = lng.split('.');
        value = ns;
        ns = path[1];
      }

      this.addNamespaces(ns);

      utils.setPath(this.data, path, value);

      if (!options.silent) this.emit('added', lng, ns, key, value);
    }
  }, {
    key: 'addResources',
    value: function addResources(lng, ns, resources) {
      for (var m in resources) {
        if (typeof resources[m] === 'string') this.addResource(lng, ns, m, resources[m], { silent: true });
      }
      this.emit('added', lng, ns, resources);
    }
  }, {
    key: 'addResourceBundle',
    value: function addResourceBundle(lng, ns, resources, deep, overwrite) {
      var path = [lng, ns];
      if (lng.indexOf('.') > -1) {
        path = lng.split('.');
        deep = resources;
        resources = ns;
        ns = path[1];
      }

      this.addNamespaces(ns);

      var pack = utils.getPath(this.data, path) || {};

      if (deep) {
        utils.deepExtend(pack, resources, overwrite);
      } else {
        pack = babelHelpers.extends({}, pack, resources);
      }

      utils.setPath(this.data, path, pack);

      this.emit('added', lng, ns, resources);
    }
  }, {
    key: 'removeResourceBundle',
    value: function removeResourceBundle(lng, ns) {
      if (this.hasResourceBundle(lng, ns)) {
        delete this.data[lng][ns];
      }
      this.removeNamespaces(ns);

      this.emit('removed', lng, ns);
    }
  }, {
    key: 'hasResourceBundle',
    value: function hasResourceBundle(lng, ns) {
      return this.getResource(lng, ns) !== undefined;
    }
  }, {
    key: 'getResourceBundle',
    value: function getResourceBundle(lng, ns) {
      if (!ns) ns = this.options.defaultNS;

      // TODO: COMPATIBILITY remove extend in v2.1.0
      if (this.options.compatibilityAPI === 'v1') return babelHelpers.extends({}, this.getResource(lng, ns));

      return this.getResource(lng, ns);
    }
  }, {
    key: 'toJSON',
    value: function toJSON() {
      return this.data;
    }
  }]);
  return ResourceStore;
}(EventEmitter);

export default ResourceStore;